@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     CompressionFormatType,
@@ -165,7 +165,7 @@ BatchDeleteRecipeVersionRequestRequestTypeDef = TypedDict(
     "BatchDeleteRecipeVersionRequestRequestTypeDef",
     {
         "Name": str,
-        "RecipeVersions": List[str],
+        "RecipeVersions": Sequence[str],
     },
 )
 
@@ -196,7 +196,7 @@ _RequiredColumnStatisticsConfigurationTypeDef = TypedDict(
 _OptionalColumnStatisticsConfigurationTypeDef = TypedDict(
     "_OptionalColumnStatisticsConfigurationTypeDef",
     {
-        "Selectors": List["ColumnSelectorTypeDef"],
+        "Selectors": Sequence["ColumnSelectorTypeDef"],
     },
     total=False,
 )
@@ -243,7 +243,7 @@ _OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
         "Format": InputFormatType,
         "FormatOptions": "FormatOptionsTypeDef",
         "PathOptions": "PathOptionsTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -281,7 +281,7 @@ _OptionalCreateProfileJobRequestRequestTypeDef = TypedDict(
         "MaxCapacity": int,
         "MaxRetries": int,
         "Configuration": "ProfileConfigurationTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "Timeout": int,
         "JobSample": "JobSampleTypeDef",
     },
@@ -316,7 +316,7 @@ _OptionalCreateProjectRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProjectRequestRequestTypeDef",
     {
         "Sample": "SampleTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -352,12 +352,12 @@ _OptionalCreateRecipeJobRequestRequestTypeDef = TypedDict(
         "LogSubscription": LogSubscriptionType,
         "MaxCapacity": int,
         "MaxRetries": int,
-        "Outputs": List["OutputTypeDef"],
-        "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
-        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
+        "Outputs": Sequence["OutputTypeDef"],
+        "DataCatalogOutputs": Sequence["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": Sequence["DatabaseOutputTypeDef"],
         "ProjectName": str,
         "RecipeReference": "RecipeReferenceTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "Timeout": int,
     },
     total=False,
@@ -382,14 +382,14 @@ _RequiredCreateRecipeRequestRequestTypeDef = TypedDict(
     "_RequiredCreateRecipeRequestRequestTypeDef",
     {
         "Name": str,
-        "Steps": List["RecipeStepTypeDef"],
+        "Steps": Sequence["RecipeStepTypeDef"],
     },
 )
 _OptionalCreateRecipeRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRecipeRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -419,8 +419,8 @@ _RequiredCreateScheduleRequestRequestTypeDef = TypedDict(
 _OptionalCreateScheduleRequestRequestTypeDef = TypedDict(
     "_OptionalCreateScheduleRequestRequestTypeDef",
     {
-        "JobNames": List[str],
-        "Tags": Dict[str, str],
+        "JobNames": Sequence[str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -908,8 +908,8 @@ DescribeScheduleResponseTypeDef = TypedDict(
 ExcelOptionsTypeDef = TypedDict(
     "ExcelOptionsTypeDef",
     {
-        "SheetNames": List[str],
-        "SheetIndexes": List[int],
+        "SheetNames": Sequence[str],
+        "SheetIndexes": Sequence[int],
         "HeaderRow": bool,
     },
     total=False,
@@ -939,7 +939,7 @@ FilterExpressionTypeDef = TypedDict(
     "FilterExpressionTypeDef",
     {
         "Expression": str,
-        "ValuesMap": Dict[str, str],
+        "ValuesMap": Mapping[str, str],
     },
 )
 
@@ -1235,7 +1235,7 @@ _OptionalOutputTypeDef = TypedDict(
     {
         "CompressionFormat": CompressionFormatType,
         "Format": OutputFormatType,
-        "PartitionColumns": List[str],
+        "PartitionColumns": Sequence[str],
         "Overwrite": bool,
         "FormatOptions": "OutputFormatOptionsTypeDef",
     },
@@ -1262,7 +1262,7 @@ PathOptionsTypeDef = TypedDict(
     {
         "LastModifiedDateCondition": "FilterExpressionTypeDef",
         "FilesLimit": "FilesLimitTypeDef",
-        "Parameters": Dict[str, "DatasetParameterTypeDef"],
+        "Parameters": Mapping[str, "DatasetParameterTypeDef"],
     },
     total=False,
 )
@@ -1271,8 +1271,8 @@ ProfileConfigurationTypeDef = TypedDict(
     "ProfileConfigurationTypeDef",
     {
         "DatasetStatisticsConfiguration": "StatisticsConfigurationTypeDef",
-        "ProfileColumns": List["ColumnSelectorTypeDef"],
-        "ColumnStatisticsConfigurations": List["ColumnStatisticsConfigurationTypeDef"],
+        "ProfileColumns": Sequence["ColumnSelectorTypeDef"],
+        "ColumnStatisticsConfigurations": Sequence["ColumnStatisticsConfigurationTypeDef"],
     },
     total=False,
 )
@@ -1346,7 +1346,7 @@ _RequiredRecipeActionTypeDef = TypedDict(
 _OptionalRecipeActionTypeDef = TypedDict(
     "_OptionalRecipeActionTypeDef",
     {
-        "Parameters": Dict[str, str],
+        "Parameters": Mapping[str, str],
     },
     total=False,
 )
@@ -1384,7 +1384,7 @@ _RequiredRecipeStepTypeDef = TypedDict(
 _OptionalRecipeStepTypeDef = TypedDict(
     "_OptionalRecipeStepTypeDef",
     {
-        "ConditionExpressions": List["ConditionExpressionTypeDef"],
+        "ConditionExpressions": Sequence["ConditionExpressionTypeDef"],
     },
     total=False,
 )
@@ -1603,15 +1603,15 @@ StatisticOverrideTypeDef = TypedDict(
     "StatisticOverrideTypeDef",
     {
         "Statistic": str,
-        "Parameters": Dict[str, str],
+        "Parameters": Mapping[str, str],
     },
 )
 
 StatisticsConfigurationTypeDef = TypedDict(
     "StatisticsConfigurationTypeDef",
     {
-        "IncludedStatistics": List[str],
-        "Overrides": List["StatisticOverrideTypeDef"],
+        "IncludedStatistics": Sequence[str],
+        "Overrides": Sequence["StatisticOverrideTypeDef"],
     },
     total=False,
 )
@@ -1636,7 +1636,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -1644,7 +1644,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1764,9 +1764,9 @@ _OptionalUpdateRecipeJobRequestRequestTypeDef = TypedDict(
         "LogSubscription": LogSubscriptionType,
         "MaxCapacity": int,
         "MaxRetries": int,
-        "Outputs": List["OutputTypeDef"],
-        "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
-        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
+        "Outputs": Sequence["OutputTypeDef"],
+        "DataCatalogOutputs": Sequence["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": Sequence["DatabaseOutputTypeDef"],
         "Timeout": int,
     },
     total=False,
@@ -1797,7 +1797,7 @@ _OptionalUpdateRecipeRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateRecipeRequestRequestTypeDef",
     {
         "Description": str,
-        "Steps": List["RecipeStepTypeDef"],
+        "Steps": Sequence["RecipeStepTypeDef"],
     },
     total=False,
 )
@@ -1827,7 +1827,7 @@ _RequiredUpdateScheduleRequestRequestTypeDef = TypedDict(
 _OptionalUpdateScheduleRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateScheduleRequestRequestTypeDef",
     {
-        "JobNames": List[str],
+        "JobNames": Sequence[str],
     },
     total=False,
 )
@@ -1857,7 +1857,7 @@ _OptionalViewFrameTypeDef = TypedDict(
     "_OptionalViewFrameTypeDef",
     {
         "ColumnRange": int,
-        "HiddenColumns": List[str],
+        "HiddenColumns": Sequence[str],
     },
     total=False,
 )
